==> tuia-news-center-common-0.0.73-lqs-20181114.020417-11-sources.jar: cn/com/duiba/tuia/news/center/enums/RedisKey.java <==
package cn.com.duiba.tuia.news.center.enums;

/**
 * @author ElinZhou
 * @version $Id: RedisKey.java , v 0.1 2017/5/19 下午4:38 ElinZhou Exp $
 */
public enum RedisKey {

    /**
     * token缓存
     */
    K49,

    /**
     * 目标不可重复性任务日完成记录ke
     */
    K50,

    /**
     * 用户领奖分布式锁
     */
    K051,

    /**
     * 用户未结算金币缓存
     */
    K52,

    /**
     * 用户昨日收益缓存
     */
    K53,

    /**
     * 用户已结算零钱总额缓存
     */
    K54,

    /**
     * 活动列表缓存
     */
    K60,

    /**
     * 用户今日获取的金币数量
     */
    K63,

    /**
     * 客户明天的阅读数量（文章加视频）
     */
    K68,

    /**
     * 版本号控制
     */
    K69,

    /**
     * 大额奖励的概率和人数
     */
    K70,

    /**
     * 今天已经大额中奖人数
     */
    K71,

    /**
     * 提现分布式锁key
     */
    K072,

    /**
     * 手机号10分钟之内的验证码相同
     */
    K75,

    /**
     * 每个设备限定每天发送20条短信
     */
    K76,
    /**
     * 一个手机号无法在55秒内重新发送短信
     */
    K78,

    /**
     *
     */
    K79,

    /**
     * 手机登陆redis锁，防止重复登陆
     */
    K80,
    /**
     * 用户第一块地的开启时间
     */
    K81,
    /**
     * 被邀请人阅读文章的自旋锁
     */
    K082,

    /**
     * 开土地的redis锁
     */
    K084,

    /**
     * 收红包的自旋锁
     */
    K85,
    /**
     * 邀请人领取被邀请人的尽奖励金
     */
    K86,
    /**
     * 是否将好友阅读限流
     */
    K87,
    /**
     * 微信好友的帮戳记录
     */
    K88,

    /**
     * 帮戳的redis锁
     */
    K089,

    /**
     * 限时红包提现锁
     */
    K090,

    /**
     * 待推送列表
     */
    K91,

    /**
     * 推送分布式锁
     */
    K092,
    /**
     * 微信的accessToken
     */
    K93,

    /**
     * 用户开启限时红包的锁
     */
    K095,
    /**
     * 微信临时token
     */
    K96,
    /**
     * 微信临时票据
     */
    K97,
    /**
     * 新人戳分布式锁
     */
    K098,
    /**
     * 微信用户信息
     */
    K99,
    /**
     * 用户分享邀请链接锁
     */
    K0100,
    /**
     * 自己上一次刷新自己农场页面的时间
     */
    K103,
    /**
     * 今日是否刷新过陌生人列表
     */
    K106,
    /**
     * 当前的陌生人列表
     */
    K107,
    /**
     * 当前可以摘取红包的userId
     */
    K108,
    /**
     * 对谁家的土地进行操作锁
     */
    K0109,
    /**
     * 	新红包农场第一次开启土地的时间
     */
    K110,
    /**
     * 	用户农场操作相关记录
     */
    K111,

    /**
     * 是否好友列表迁移过邀请列Redis表
     */
    K112,
    /**
     * 今日是否获取过邀请奖励金
     */
    K113,
    /**
     * 用户收取小蜜的最后时间
     */
    K115,
    /**
     * 判断今日给狗咬的次数
     */
    K114,
    /**
     *  获取狗道具的缓存
     */
    K116,
    /**
     * 缓存一二个红包的Id
     */
    K117,
    /**
     * 添加好友申请
     */
    K118,
    /**
     * 处理好友申请
     */
    K119,
    /**
     * 分发双倍加分布式锁
     */
    K0121,
    /**
     * 拼手气红包预发的redis数据
     */
    K122,
    /**
     * 用户获取拼手气红包的次数
     */
    K123,

    /**
     * 拼手气红包有待入账推送计数
     */
    K124,

    /**
     * 收取群红包动作上锁
     */
    K125,


    /**
     * 极光待打tag列表
     */
    K126,
    /**
     * 极光待打tag分布式锁
     */
    K127,

    /**
     * 红包带收取
     */
    K128,
    /**
     *app用户玩点点赚的当日的记录
     */
    K131,

    /**
     *微信用户当日的点点赚记录
     */
    K132,

    /**
     * 打开点点赚帮助增加次数的记录
     */
    K133,
    /**
     *app用户点点赚抽奖接口分布式锁
     */
    K0134,
    /**
     *微信用户点点赚抽奖接口分布式锁
     */
    K0135,

    /**
     * 点点赚用户的操作记录
     */
    K136,

    /**
     * 群红包用户当天发红包次数记录
     */
    K139,

    /**

     * 点点赚用户提现R
     */
    K142,

    /*
     * 用户每日任务
     */
    K140,

    /**
     * 签到接口分布式锁
     */
    K0143,

    /**
     * 用户已阅读文章数量
     */
    K144,

    /**
     * 用户签到分享文案
     */
    K145,

    /**
     * 用户领取打卡奖励标志
     */
    K146,

    /**
     * 用户帮助别的用户增加打卡分享奖励记录
     */
    K147,

    /**
     * 领取日常任务锁
     */
    K159,

    /**
     * 被邀请者对应的邀请数据
     */
    K157,

    /**
     * 用户今日金币余额
     */
    K158,

    /**
     * 是否初始化完新红包农场
     */
    K160,


    /**
     * 获取用户的可偷红包Id
     */
    K179,

    /*
     * 随机用户列表
     */
    K166,

    /**
     * 获取日常任务奖励接口
     */
    K171,

    /**
     * 缓存用户新手奖励状态
     */
    K172,

    /**
     * 缓存日常任务状态
     */
    K173,

    /**
     * 添加仇敌加锁
     */
    K175,

    /**
     * 那个户签到第一天的奖励金
     */
    K187,

    /**
     * 将还在有效期的看门狗存入redis的key
     */
    K176,

    /**
     * 用户可用余额缓存
     */
    K177,

    /**
     * 用户已偷取红包
     */
    K195,

    /**
     * 	用户获取新版解锁奖励金的缓存
     */
    K189,


    /**
     * 用户金币日余额记录id缓存
     */
    K184,

    /**
     * 用户微信验证信息
     */
    K185,

    /**
     * 用户微信验证信息(openId)
     */
    K186,

    /**
     * 用户待解锁红包
     */
    K181,

    /**
     * 用户极光注册id
     */
    K183,

    /**
     * 获取用户最新的一个将要成熟红包
     */
    K190,
    /*
     * 登录用户对应的手机号
     */
    K178,
    /**
     * 用户任务信息缓存
     */
    K180,

    /**
     * 获取任务体系接口
     */
    K192,
    /*
     * 签到获取IMEI码分布式锁
     */
    K191,

    /**
     * 极光推送插入regId分布式锁
     */
    K198,

    /**
     * 用户详情缓存
     */
    K200,

    /**
     * 用户土地情况缓存
     */
    K201,

    /**
     * 用户行为缓存
     */
    K202,

    /**
     * 一个用户一天一次刷新初始化任务
     */
    K205,

    /**
     * 初始化任务的锁
     */
    K206,

    /**
     * 被邀请者的被邀请记录
     */
    K222,
    /**
     * 用户的打狗棒数量
     */
    K225,

    /**
     * 我的页面配置
     */
    K221,

    /**
     * 新人引导阅读奖励标志
     */
    K226,

    /**
     * 对应日期的汇率
     */
    K227,

    /**
     * 用户行为数量批量更新用户集合
     */
    K229,

    /**
     * 用户已阅读文章数量V2
     */
    K230,

    /**用户插入领取特权券的记录
     *
     */
    K242
    ;


}

==> tuia-news-center-common-1.8.0.0-lqs-20181226.055611-1-sources.jar: cn/com/duiba/tuia/news/center/enums/RedisKey.java <==
package cn.com.duiba.tuia.news.center.enums;

/**
 * @author ElinZhou
 * @version $Id: RedisKey.java , v 0.1 2017/5/19 下午4:38 ElinZhou Exp $
 */
public enum RedisKey {

    /**
     * token缓存
     */
    K49,

    /**
     * 目标不可重复性任务日完成记录ke
     */
    K50,

    /**
     * 用户领奖分布式锁
     */
    K051,

    /**
     * 用户未结算金币缓存
     */
    K52,

    /**
     * 用户昨日收益缓存
     */
    K53,

    /**
     * 用户已结算零钱总额缓存
     */
    K54,

    /**
     * 活动列表缓存
     */
    K60,

    /**
     * 用户今日获取的金币数量
     */
    K63,

    /**
     * 客户明天的阅读数量（文章加视频）
     */
    K68,

    /**
     * 版本号控制
     */
    K69,

    /**
     * 大额奖励的概率和人数
     */
    K70,

    /**
     * 今天已经大额中奖人数
     */
    K71,

    /**
     * 提现分布式锁key
     */
    K072,

    /**
     * 手机号10分钟之内的验证码相同
     */
    K75,

    /**
     * 每个设备限定每天发送20条短信
     */
    K76,
    /**
     * 一个手机号无法在55秒内重新发送短信
     */
    K78,

    /**
     *
     */
    K79,

    /**
     * 手机登陆redis锁，防止重复登陆
     */
    K80,
    /**
     * 用户第一块地的开启时间
     */
    K81,
    /**
     * 被邀请人阅读文章的自旋锁
     */
    K082,

    /**
     * 开土地的redis锁
     */
    K084,

    /**
     * 收红包的自旋锁
     */
    K85,
    /**
     * 邀请人领取被邀请人的尽奖励金
     */
    K86,
    /**
     * 是否将好友阅读限流
     */
    K87,
    /**
     * 微信好友的帮戳记录
     */
    K88,

    /**
     * 帮戳的redis锁
     */
    K089,

    /**
     * 限时红包提现锁
     */
    K090,

    /**
     * 待推送列表
     */
    K91,

    /**
     * 推送分布式锁
     */
    K092,
    /**
     * 微信的accessToken
     */
    K93,

    /**
     * 用户开启限时红包的锁
     */
    K095,
    /**
     * 微信临时token
     */
    K96,
    /**
     * 微信临时票据
     */
    K97,
    /**
     * 新人戳分布式锁
     */
    K098,
    /**
     * 微信用户信息
     */
    K99,
    /**
     * 用户分享邀请链接锁
     */
    K0100,
    /**
     * 自己上一次刷新自己农场页面的时间
     */
    K103,
    /**
     * 今日是否刷新过陌生人列表
     */
    K106,
    /**
     * 当前的陌生人列表
     */
    K107,
    /**
     * 当前可以摘取红包的userId
     */
    K108,
    /**
     * 对谁家的土地进行操作锁
     */
    K0109,
    /**
     * 	新红包农场第一次开启土地的时间
     */
    K110,
    /**
     * 	用户农场操作相关记录
     */
    K111,

    /**
     * 是否好友列表迁移过邀请列Redis表
     */
    K112,
    /**
     * 今日是否获取过邀请奖励金
     */
    K113,
    /**
     * 用户收取小蜜的最后时间
     */
    K115,
    /**
     * 判断今日给狗咬的次数
     */
    K114,
    /**
     *  获取狗道具的缓存
     */
    K116,
    /**
     * 缓存一二个红包的Id
     */
    K117,
    /**
     * 添加好友申请
     */
    K118,
    /**
     * 处理好友申请
     */
    K119,
    /**
     * 分发双倍加分布式锁
     */
    K0121,
    /**
     * 拼手气红包预发的redis数据
     */
    K122,
    /**
     * 用户获取拼手气红包的次数
     */
    K123,

    /**
     * 拼手气红包有待入账推送计数
     */
    K124,

    /**
     * 收取群红包动作上锁
     */
    K125,


    /**
     * 极光待打tag列表
     */
    K126,
    /**
     * 极光待打tag分布式锁
     */
    K127,

    /**
     * 红包带收取
     */
    K128,
    /**
     *app用户玩点点赚的当日的记录
     */
    K131,

    /**
     *微信用户当日的点点赚记录
     */
    K132,

    /**
     * 打开点点赚帮助增加次数的记录
     */
    K133,
    /**
     *app用户点点赚抽奖接口分布式锁
     */
    K0134,
    /**
     *微信用户点点赚抽奖接口分布式锁
     */
    K0135,

    /**
     * 点点赚用户的操作记录
     */
    K136,

    /**
     * 群红包用户当天发红包次数记录
     */
    K139,

    /**

     * 点点赚用户提现R
     */
    K142,

    /*
     * 用户每日任务
     */
    K140,

    /**
     * 签到接口分布式锁
     */
    K0143,

    /**
     * 用户已阅读文章数量
     */
    K144,

    /**
     * 用户签到分享文案
     */
    K145,

    /**
     * 用户领取打卡奖励标志
     */
    K146,

    /**
     * 用户帮助别的用户增加打卡分享奖励记录
     */
    K147,

    /**
     * 领取日常任务锁
     */
    K159,

    /**
     * 被邀请者对应的邀请数据
     */
    K157,

    /**
     * 用户今日金币余额
     */
    K158,

    /**
     * 是否初始化完新红包农场
     */
    K160,


    /**
     * 获取用户的可偷红包Id
     */
    K179,

    /*
     * 随机用户列表
     */
    K166,

    /**
     * 获取日常任务奖励接口
     */
    K171,

    /**
     * 缓存用户新手奖励状态
     */
    K172,

    /**
     * 缓存日常任务状态
     */
    K173,

    /**
     * 添加仇敌加锁
     */
    K175,

    /**
     * 那个户签到第一天的奖励金
     */
    K187,

    /**
     * 将还在有效期的看门狗存入redis的key
     */
    K176,

    /**
     * 用户可用余额缓存
     */
    K177,

    /**
     * 用户已偷取红包
     */
    K195,

    /**
     * 	用户获取新版解锁奖励金的缓存
     */
    K189,


    /**
     * 用户金币日余额记录id缓存
     */
    K184,

    /**
     * 用户微信验证信息
     */
    K185,

    /**
     * 用户微信验证信息(openId)
     */
    K186,

    /**
     * 用户待解锁红包
     */
    K181,

    /**
     * 用户极光注册id
     */
    K183,

    /**
     * 获取用户最新的一个将要成熟红包
     */
    K190,
    /*
     * 登录用户对应的手机号
     */
    K178,
    /**
     * 用户任务信息缓存
     */
    K180,

    /**
     * 获取任务体系接口
     */
    K192,
    /*
     * 签到获取IMEI码分布式锁
     */
    K191,

    /**
     * 极光推送插入regId分布式锁
     */
    K198,

    /**
     * 用户详情缓存
     */
    K200,

    /**
     * 用户土地情况缓存
     */
    K201,

    /**
     * 用户行为缓存
     */
    K202,

    /**
     * 一个用户一天一次刷新初始化任务
     */
    K205,

    /**
     * 初始化任务的锁
     */
    K206,

    /**
     * 被邀请者的被邀请记录
     */
    K222,
    /**
     * 用户的打狗棒数量
     */
    K225,

    /**
     * 我的页面配置
     */
    K221,

    /**
     * 新人引导阅读奖励标志
     */
    K226,

    /**
     * 对应日期的汇率
     */
    K227,

    /**
     * 用户行为数量批量更新用户集合
     */
    K229,

    /**
     * 用户已阅读文章数量V2
     */
    K230,

    /**用户插入领取特权券的记录
     *
     */
    K242,


    /**
    * 1.6.1版本用户获取的奖励的文章Id的List
     */
    K252,
    /*
     *二级以及子城市列表缓存
     */
    K250,

    /*
    *一级以及子城市列表缓存
    */
    K253,

    /**
     * 用户领取实物奖励的记录
     */
    K262,

    /**
     * 用户获取实物奖励的锁
     */
    K263,

    /*
     * 红包农场仇敌及状态缓存
     */
    K255,

    /**
     * 用户土地被偷列表
     */
    K258,

    /**用户当前任务执行的进度 */
    K266,

    /**用户当前任务完成的进度  */
    K267,

    /**
     * 数据源切换开关
     */
    KEY02,

    /**
     *当日金币收益风控
     */
    K268,

    /**
     *最近7日金币收益风控
     */
    K269,

    /**
     * 合伙人信息缓存
     */
    K274,

    /**
     * 增量更新pdd订单时维护的pid列表
     */
    K278,

    /**
     * 上次同步pdd订单的时间
     */
    K280,

    /** 用户当前任务的完成状态 */
    K272,

    /** 用户当前的所有通知 */
    K275,

    /** 最新的30条系统通知 */
    K276,

    /*阅读奖励列表储存	*/
    K283,

    /*用户绑定手机号的分布式锁*/
    K285,

    /*用户首次提现可获取奖励的标志位*/
    K289,

    /**
     * 用户阅读数排行榜
     */
    K290,

    /*用户新人任务列表缓存	*/
    K291,

    /*更新新人任务的分布式锁*/
    K292,
    /**
     * 新用户获取第一次提现奖励接口分布式锁
     */
    K297,

    /*预发环境微信临时ticket*/
    K293,

    /**
     * 小程序用户每日金币收益上限
     */
    K294,

    /**
     * 小程序用户分享文章记录
     */
    K295,

    /**
     * 用户分享回访的收益
     */
    K296,

    /**
     * 微信access_token
     */
    K298,
    ;

}
